@@ -26,7 +26,7 @@ system_fields = [
     "sys_dirty",
     "sys_table",
     "sys_modified_count",
-    "description",
+    "sys_keywords",
 ]
 
 
@@ -379,7 +379,7 @@ CREATE TABLE {table_identifier} (
   "sys_modified_by" TEXT,
   "sys_modified_count" INTEGER NOT NULL DEFAULT 0,
   "sys_dirty" INTEGER NOT NULL DEFAULT 0,
-  "description" TEXT
+                            "sys_keywords" TEXT
 );
 """.strip()
         )
@@ -431,18 +431,46 @@ END;
         return "\n".join(statements), tuple()
 
     @classmethod
-    def ensure_sys_modified_count(cls, name):
-        """Ensure sys_modified_count exists for SQLite tables."""
+    def ensure_system_columns(
+        cls,
+        name,
+        existing_columns=None,
+        force=False,
+        existing_indexes=None,
+    ):
+        """Ensure SQLite tables maintain the Velocity system triggers/columns."""
+        existing_columns = {col.lower() for col in existing_columns or []}
+
         table_identifier = quote(name)
         base_name = name.split(".")[-1].replace('"', "")
         base_name_sql = base_name.replace("'", "''")
         trigger_prefix = re.sub(r"[^0-9A-Za-z_]+", "_", f"cc_sysmod_{base_name}")
-        statements = [
-            f"ALTER TABLE {table_identifier} ADD COLUMN sys_modified_count INTEGER NOT NULL DEFAULT 0;",
-            f"UPDATE {table_identifier} SET sys_modified_count = 0 WHERE sys_modified_count IS NULL;",
-            f"DROP TRIGGER IF EXISTS {trigger_prefix}_ai;",
-            f"DROP TRIGGER IF EXISTS {trigger_prefix}_au;",
-            f"""
+
+        has_count = "sys_modified_count" in existing_columns
+
+        add_column = not has_count
+        recreate_triggers = force or add_column
+
+        if not recreate_triggers and not force:
+            return None
+
+        statements = []
+
+        if add_column:
+            statements.append(
+                f"ALTER TABLE {table_identifier} ADD COLUMN sys_modified_count INTEGER NOT NULL DEFAULT 0;"
+            )
+
+        statements.append(
+            f"UPDATE {table_identifier} SET sys_modified_count = 0 WHERE sys_modified_count IS NULL;"
+        )
+
+        statements.append(f"DROP TRIGGER IF EXISTS {trigger_prefix}_ai;")
+        statements.append(f"DROP TRIGGER IF EXISTS {trigger_prefix}_au;")
+
+        statements.extend(
+            [
+                f"""
 CREATE TRIGGER {trigger_prefix}_ai
 AFTER INSERT ON {table_identifier}
 FOR EACH ROW
@@ -456,7 +484,7 @@ BEGIN
     WHERE rowid = NEW.rowid;
 END;
 """.strip(),
-            f"""
+                f"""
 CREATE TRIGGER {trigger_prefix}_au
 AFTER UPDATE ON {table_identifier}
 FOR EACH ROW
@@ -470,7 +498,9 @@ BEGIN
     WHERE rowid = NEW.rowid;
 END;
 """.strip(),
-        ]
+            ]
+        )
+
         return "\n".join(statements), tuple()
 
     @classmethod
